@@ -1,6 +1,5 @@
 #include <config.h>
 #include <glib/gi18n.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
 
 #include "eog-info-view.h"
 #include "eog-info-view-file.h"
@@ -35,6 +34,8 @@ eog_info_view_dispose (GObject *object)
 		eog_image_data_unref (priv->image);
 		priv->image = NULL;
 	}
+
+	G_OBJECT_CLASS (eog_info_view_parent_class)->dispose (object);
 }
 
 static void
@@ -47,6 +48,8 @@ eog_info_view_finalize (GObject *object)
 	g_free (view->priv);
 
 	view->priv = NULL;
+
+	G_OBJECT_CLASS (eog_info_view_parent_class)->finalize (object);
 }
 
 static void
