@@ -2,8 +2,6 @@
 #include <config.h>
 #endif
 
-#include <libgnome/gnome-macros.h>
-
 #include "eog-job.h"
 
 static guint last_job_id = 0;
@@ -37,6 +35,8 @@ struct _EogJobPrivate {
 	EogJobFreeDataFunc df;
 };
 
+G_DEFINE_TYPE (EogJob, eog_job,	G_TYPE_OBJECT)
+
 static void
 eog_job_set_property (GObject      *object,
 		      guint         property_id,
@@ -104,6 +104,8 @@ eog_job_finalize (GObject *object)
 	
 	g_free (instance->priv);
 	instance->priv = NULL;
+
+	G_OBJECT_CLASS (eog_job_parent_class)->finalize (object);
 }
 
 static void
@@ -138,6 +140,7 @@ eog_job_dispose (GObject *object)
 #if DEBUG_EOG_JOB
 	g_print ("Job %.3u: disposing end\n", priv->id);
 #endif
+	G_OBJECT_CLASS (eog_job_parent_class)->dispose (object);
 }
 
 static void
@@ -214,9 +217,6 @@ eog_job_class_init (EogJobClass *klass)
 				   G_PARAM_WRITABLE));
 }
 
-
-G_DEFINE_TYPE (EogJob, eog_job,	G_TYPE_OBJECT)
-
 EogJob*             
 eog_job_new (GObject *data_obj, 
 	     EogJobActionFunc   af, 
