@@ -3,7 +3,6 @@
 #endif
 
 #include <string.h>
-#include <libgnome/gnome-macros.h>
 
 #include "eog-metadata-reader.h"
 
@@ -46,6 +45,8 @@ struct _EogMetadataReaderPrivate {
 	int      bytes_read;	
 };
 
+G_DEFINE_TYPE (EogMetadataReader, eog_metadata_reader, G_TYPE_OBJECT)
+
 static void
 eog_metadata_reader_finalize (GObject *object)
 {
@@ -53,6 +54,8 @@ eog_metadata_reader_finalize (GObject *object)
 	
 	g_free (instance->priv);
 	instance->priv = NULL;
+
+	G_OBJECT_CLASS (eog_metadata_reader_parent_class)->finalize (object);
 }
 
 static void
@@ -74,6 +77,8 @@ eog_metadata_reader_dispose (GObject *object)
 		g_free (emr->priv->icc_chunk);
 		emr->priv->icc_chunk = NULL;
 	}
+
+	G_OBJECT_CLASS (eog_metadata_reader_parent_class)->dispose (object);
 }
 
 static void
@@ -101,9 +106,6 @@ eog_metadata_reader_class_init (EogMetadataReaderClass *klass)
 	object_class->dispose = eog_metadata_reader_dispose;
 }
 
-
-G_DEFINE_TYPE (EogMetadataReader, eog_metadata_reader, G_TYPE_OBJECT)
-
 EogMetadataReader*
 eog_metadata_reader_new (EogMetadataFileType type)
 {
@@ -228,13 +230,13 @@ eog_metadata_reader_consume (EogMetadataReader *emr, guchar *buf, guint len)
 
 			if (i + priv->size < len) {
                                 /* read data in one block */
-				memcpy ((void*) ((int)(priv->exif_chunk) + priv->bytes_read), (void*)&buf[i], priv->size); 
+				memcpy ((guchar*) (priv->exif_chunk) + priv->bytes_read, &buf[i], priv->size);
 				priv->state = EMR_READ;
 				i = i + priv->size - 1; /* the for-loop consumes the other byte */
 			}
 			else {
 				int chunk_len = len - i;
-				memcpy ((void*)((int)priv->exif_chunk + priv->bytes_read), (void*)&buf[i], chunk_len);
+				memcpy ((guchar*) (priv->exif_chunk) + priv->bytes_read, &buf[i], chunk_len);
 				priv->bytes_read += chunk_len; /* bytes already read */
 				priv->size = (i + priv->size) - len; /* remaining data to read */
 				i = len - 1;
@@ -257,13 +259,13 @@ eog_metadata_reader_consume (EogMetadataReader *emr, guchar *buf, guint len)
 
 			if (i + priv->size < len) {
 				/* read data in one block */
-				memcpy ((void*) ((int)(priv->icc_chunk) + priv->bytes_read), (void*)&buf[i], priv->size); 
+				memcpy ((guchar*) (priv->icc_chunk) + priv->bytes_read, &buf[i], priv->size); 
 				priv->state = EMR_READ;
 				i = i + priv->size - 1; /* the for-loop consumes the other byte */
 			}
 			else {
 				int chunk_len = len - i;
-				memcpy ((void*)((int)priv->icc_chunk + priv->bytes_read), (void*)&buf[i], chunk_len);
+				memcpy ((guchar*) (priv->icc_chunk) + priv->bytes_read, &buf[i], chunk_len);
 				priv->bytes_read += chunk_len; /* bytes already read */
 				priv->size = (i + priv->size) - len; /* remaining data to read */
 				i = len - 1;
@@ -283,12 +285,12 @@ eog_metadata_reader_consume (EogMetadataReader *emr, guchar *buf, guint len)
 
 			if (i + priv->size < len) {
                                 /* read data in one block */
-				memcpy ((void*)((int)priv->iptc_chunk + priv->bytes_read), (void*)&buf[i], priv->size); 
+				memcpy ((guchar*) (priv->iptc_chunk) + priv->bytes_read, &buf[i], priv->size); 
 				priv->state = EMR_READ;
 			}
 			else {
 				int chunk_len = len - i;
-				memcpy ((void*)((int)priv->iptc_chunk + priv->bytes_read), (void*)&buf[i], chunk_len);
+				memcpy ((guchar*) (priv->iptc_chunk) + priv->bytes_read, &buf[i], chunk_len);
 				priv->bytes_read += chunk_len; /* bytes already read */
 				priv->size = (i + priv->size) - len; /* remaining data to read */
 				i = len - 1;
